Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(34)

Unified Diff: webrtc/modules/audio_mixer/audio_frame_manipulator.h

Issue 2238803002: Changed folder structure in new mixer and fixed simple lint errors. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Small changes in response to comments. Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webrtc/modules/audio_mixer/BUILD.gn ('k') | webrtc/modules/audio_mixer/audio_frame_manipulator.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/modules/audio_mixer/audio_frame_manipulator.h
diff --git a/webrtc/modules/audio_conference_mixer/source/audio_frame_manipulator.h b/webrtc/modules/audio_mixer/audio_frame_manipulator.h
similarity index 61%
copy from webrtc/modules/audio_conference_mixer/source/audio_frame_manipulator.h
copy to webrtc/modules/audio_mixer/audio_frame_manipulator.h
index c136597fc37df7b16bb9e791732c9943197df7da..58103addebba945dc51779477d610b62123d2acf 100644
--- a/webrtc/modules/audio_conference_mixer/source/audio_frame_manipulator.h
+++ b/webrtc/modules/audio_mixer/audio_frame_manipulator.h
@@ -8,8 +8,8 @@
* be found in the AUTHORS file in the root of the source tree.
*/
-#ifndef WEBRTC_MODULES_AUDIO_CONFERENCE_MIXER_SOURCE_AUDIO_FRAME_MANIPULATOR_H_
-#define WEBRTC_MODULES_AUDIO_CONFERENCE_MIXER_SOURCE_AUDIO_FRAME_MANIPULATOR_H_
+#ifndef WEBRTC_MODULES_AUDIO_MIXER_AUDIO_FRAME_MANIPULATOR_H_
+#define WEBRTC_MODULES_AUDIO_MIXER_AUDIO_FRAME_MANIPULATOR_H_
#include "webrtc/typedefs.h"
@@ -17,12 +17,12 @@ namespace webrtc {
class AudioFrame;
// Updates the audioFrame's energy (based on its samples).
-uint32_t CalculateEnergy(const AudioFrame& audioFrame);
+uint32_t NewMixerCalculateEnergy(const AudioFrame& audio_frame);
-// Apply linear step function that ramps in/out the audio samples in audioFrame
-void RampIn(AudioFrame& audioFrame);
-void RampOut(AudioFrame& audioFrame);
+// Apply linear step function that ramps in/out the audio samples in audio_frame
+void NewMixerRampIn(AudioFrame* audio_frame);
+void NewMixerRampOut(AudioFrame* audio_frame);
} // namespace webrtc
-#endif // WEBRTC_MODULES_AUDIO_CONFERENCE_MIXER_SOURCE_AUDIO_FRAME_MANIPULATOR_H_
+#endif // WEBRTC_MODULES_AUDIO_MIXER_AUDIO_FRAME_MANIPULATOR_H_
« no previous file with comments | « webrtc/modules/audio_mixer/BUILD.gn ('k') | webrtc/modules/audio_mixer/audio_frame_manipulator.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698